#!/bin/sh
## Firewall para Casa
## Keivin Wedell Reyes Gutiérrez
## =================================
## Res publica non dominetur
## =================================
## Última Actualización: 2009.02.07
## 
## clear
echo
echo -n Van las reglas de Firewall...
echo

## FLUSH de reglas
iptables -F
iptables -X
iptables -Z
iptables -t nat -F

## Establecemos politica por defecto
iptables -P INPUT  ACCEPT
iptables -P OUTPUT ACCEPT
iptables -P FORWARD ACCEPT

# Con esto permitimos hacer forward de paquetes en el firewall, o sea
# que otras maquinas puedan salir a traves del firewall.
iptables -A INPUT -s 0/0 -p tcp --dport 80 -j ACCEPT

# Permitimos el acceso a CPUs que la hagan de servidor Web
# Acepto conexiones al puerto 80 HTTP de las siguientes IPs
#iptables -t nat -A PREROUTING -i eth0 -p tcp --dport 80 -j DNAT --to 192.168.0.221:80
#iptables -t nat -A PREROUTING -i eth0 -p tcp --dport 80 -j DNAT --to 192.168.0.180:80

# Acepto conexiones al puerto 21 FTP de las siguientes IPs
#iptables -t nat -A PREROUTING -i eth0 -p tcp --dport 21 -j DNAT --to 192.168.0.221:21
#iptables -t nat -A PREROUTING -i eth0 -p tcp --dport 21 -j DNAT --to 192.168.0.180:21

# Acepto conexiones al puerto 10000 Webmin de las siguientes IPs
#iptables -t nat -A PREROUTING -i eth0 -p tcp --dport 10000 -j DNAT --to 192.168.0.1:10000
#iptables -t nat -A PREROUTING -i eth0 -p tcp --dport 10000 -j DNAT --to 192.168.0.1:10000

#iptables -t nat -A PREROUTING -i eth1 -p tcp --dport 80 -j DNAT --to 192.168.0.221:80

echo 1 > /proc/sys/net/ipv4/ip_forward


## Empezamos a filtrar
## =========================================================
## eth1 se conecta al router Prodigy, IP asignada por DHCP.
## eth0 se conecta al switch, IP Estática con servidor DCHP en la clase 192.168.0.0
## =========================================================
## El localhost se permite

iptables -A INPUT -i lo -j ACCEPT

## Aquí ponemos las IPS a las cuales deseamos bloquear todo.
IPS_BLOQUEADAS=""
for BLOQUEA in $IPS_BLOQUEADAS; do
iptables -A INPUT -s $BLOQUEA -j DROP
iptables -A OUTPUT -s $BLOQUEA -j DROP
iptables -A FORWARD -s $BLOQUEA -p TCP --dport 1863 -j REJECT
iptables -A FORWARD -s $BLOQUEA -p UDP --dport 1863 -j REJECT
done

IPS_LABORATORIO="192.168.0.21 192.168.0.22 192.168.0.23 192.168.0.41 192.168.0.25 192.168.0.26 192.168.0.27 192.168.0.28 192.168.0.29 192.168.0.30 192.168.0.31 192.168.0.32 192.168.0.33 192.168.0.34 192.168.0.35 192.168.0.36 192.168.0.37 192.168.0.38 192.168.0.39 192.168.0.41 192.168.0.42 192.168.0.43 192.168.0.44 192.168.0.45 192.168.0.46 192.168.0.47 192.168.0.48 192.168.0.49 192.168.0.50"
for BLOQUEA in $IPS_LABORATORIO; do
iptables -A INPUT -s $BLOQUEA -j DROP
iptables -A OUTPUT -s $BLOQUEA -j DROP
iptables -A FORWARD -s $BLOQUEA -p TCP --dport 1863 -j REJECT
iptables -A FORWARD -s $BLOQUEA -p UDP --dport 1863 -j REJECT
done

# Al firewall tenemos acceso desde la red local (Solo desde la Red 253)
iptables -A INPUT -s 192.168.0.0/24 -i eth1 -j ACCEPT

# Puertos 80 redirigimos al 3128 del squid
# Para la clase 192.168.0.x 192.168.2.x
iptables -t nat -A PREROUTING -s 192.168.0.0/24 -i eth1 -p tcp --dport 80 -j REDIRECT --to-port 3128

#iptables -A FORWARD -i eth0 -o eth0 -p TCP --sport 1024:65535 --dport ftp -j ACCEPT
#iptables -A FORWARD -i eth0 -o eth0 -p TCP --syn --sport ftp --dport 1024:65535 -j ACCEPT

#ICMP
iptables -A INPUT -i eth1 -p icmp -j ACCEPT
iptables -A OUTPUT -o eth1 -p icmp -j ACCEPT 

iptables -A FORWARD -i eth1 -p icmp -j ACCEPT
iptables -A FORWARD -o eth1 -p icmp -j ACCEPT

# Acceso a FTP
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 20:21 -j ACCEPT
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 20:21 -j ACCEPT

# Acceso a SSH
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 22 -j ACCEPT
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 22 -j ACCEPT

# Aceptamos que consulten los DNS
#############################################################################
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 53 -j ACCEPT
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 53 -j ACCEPT

# Acceso a MSN Messenger
#############################################################################
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 1863 -j ACCEPT
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 1863 -j ACCEPT

#iptables -t nat -A PREROUTING -s 192.168.0.0/24 -i eth1 -p tcp --dport 1863 -j REDIRECT --to-port 3128
#iptables -t nat -A PREROUTING -s 192.168.0.0/24 -i eth1 -p tcp --dport 1863 -j REDIRECT --to-port 3128


############################
# Bloqueamos programas P2P #
############################
# eMule
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 4661:4670 -j DROP
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 4661:4670 -j DROP
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 5662 -j DROP
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 5662 -j DROP

# Azureus
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 6881:6890 -j DROP
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 6881:6890 -j DROP

# Audiogalaxy
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 41000:50000 -j DROP
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 41000:50000 -j DROP

# Kazaa
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 1214 -j DROP
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 1214 -j DROP

# Napster
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 6699 -j DROP
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 6699 -j DROP

# Realaudio
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 7070 -j DROP
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 6970:7170 -j DROP

# Shoutcast
#iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 8000:8005 -j DROP
#iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 8000:8005 -j DROP

# BitTorrent
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 6881:6999 -j DROP
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 6881:6999 -j DROP

# Ares, Limewire, eDonkey, uTorrent
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 5001:5004 -j DROP
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 5001:5004 -j DROP

#########################################
# Permitimos acceso a programas comunes #
#########################################

# Acceso a Yahoo Messenger
#############################################################################
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 5050 -j ACCEPT
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 5050 -j ACCEPT

# Acceso a SSL
##############################################################################
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 443 -j ACCEPT
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 443 -j ACCEPT

# Acceso a VoIP
##############################################################################
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 4569 -j ACCEPT
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 4569 -j ACCEPT

#################
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 5060 -j ACCEPT
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 5060 -j ACCEPT

#Compranet
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 8000:8010 -j ACCEPT

#Puerto de administracion Webmin
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 10111 -j ACCEPT
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 10111 -j ACCEPT

iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 10000 -j ACCEPT
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 10000 -j ACCEPT

#Puerto de adicionales 
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 8443 -j ACCEPT
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 8443 -j ACCEPT

iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p tcp --dport 8081 -j ACCEPT
iptables -A FORWARD -s 192.168.0.0/24 -i eth1 -p udp --dport 8081 -j ACCEPT

# Y denegamos el resto. Si se necesita alguno, ya avisaran... :p
iptables -A FORWARD -s 192.168.0.0/24 -i eth0 -j DROP

# Ahora hacemos enmascaramiento de la red local
# y activamos el BIT DE FORWARDING 
iptables -t nat -A POSTROUTING -s 192.168.0.0/24 -o eth0 -j MASQUERADE

echo ""
echo "Listo, verifica lo que se aplica con el comando:"
echo ""
echo "         iptables -L -n"
echo ""
echo "Dudas, comentarios o sugerencias, enviar un e-mail a:"
echo "keivinwedell@gmail.com"
echo ""
echo "¡Que tengas un buen día!"
echo ""

# Fin del script
